@@ -40,13 +40,11 @@ module HIndent.Pretty.Types
   , ModuleNameWithPrefix(..)
   , PatInsidePatDecl(..)
   , LambdaCase(..)
-  , ModuleDeprecatedPragma(..)
   , ListComprehension(..)
   , DoExpression(..)
   , DoOrMdo(..)
   , QualifiedDo(..)
   , LetIn(..)
-  , NodeComments(..)
   , GRHSExprType(..)
   , GRHSProcType(..)
   , HsTypeFor(..)
@@ -55,9 +53,9 @@ module HIndent.Pretty.Types
   , DataFamInstDeclFor(..)
   ) where
 
+import Data.List.NonEmpty
 import GHC.Hs
 import GHC.Types.Name.Reader
-import GHC.Unit.Module.Warnings
 #if !MIN_VERSION_ghc_lib_parser(9,6,1)
 import GHC.Unit
 #endif
@@ -255,19 +253,11 @@ data LambdaCase = LambdaCase
   { lamCaseGroup :: MatchGroup GhcPs (LHsExpr GhcPs)
   , caseOrCases :: CaseOrCases
   }
-#if MIN_VERSION_ghc_lib_parser(9,4,1)
--- | A deprecation pragma for a module.
-newtype ModuleDeprecatedPragma =
-  ModuleDeprecatedPragma (WarningTxt GhcPs)
-#else
--- | A deprecation pragma for a module.
-newtype ModuleDeprecatedPragma =
-  ModuleDeprecatedPragma WarningTxt
-#endif
+
 -- | Use this type to pretty-print a list comprehension.
 data ListComprehension = ListComprehension
   { listCompLhs :: ExprLStmt GhcPs -- ^ @f x@ of @[f x| x <- xs]@.
-  , listCompRhs :: [ExprLStmt GhcPs] -- ^ @x <- xs@ of @[f x| x <- xs]@.
+  , listCompRhs :: NonEmpty (ExprLStmt GhcPs) -- ^ @x <- xs@ of @[f x| x <- xs]@.
   }
 
 -- | Use this type to pretty-print a do expression.
@@ -282,21 +272,6 @@ data LetIn = LetIn
   , inExpr :: LHsExpr GhcPs
   }
 
--- | Comments belonging to an AST node.
-data NodeComments = NodeComments
-  { commentsBefore :: [LEpaComment]
-  , commentsOnSameLine :: [LEpaComment]
-  , commentsAfter :: [LEpaComment]
-  }
-
-instance Semigroup NodeComments where
-  x <> y =
-    NodeComments
-      { commentsBefore = commentsBefore x <> commentsBefore y
-      , commentsOnSameLine = commentsOnSameLine x <> commentsOnSameLine y
-      , commentsAfter = commentsAfter x <> commentsAfter y
-      }
-
 -- | Values indicating whether `do` or `mdo` is used.
 data DoOrMdo
   = Do
